const fs = require('fs')

module.exports = async ctx => {
    const url = 'https://cn.bing.com/HPImageArchive.aspx?format=js&idx=0&n=1'
    const res = await ctx.httpclient.request(url)
    if (res.status === 200) {
        const info = JSON.parse(res.data.toString())
        for (let img of info.images) {
            const wallpaper = {
                date: img.enddate,
                url: 'https://cn.bing.com' + img.url,
                name: img.copyright,
                title: img.title
            }
            await saveFileToCloudStorage(ctx, wallpaper)
        }
    } else {
        ctx.logger.error(`get url error: ${res.status}`)
    }
}

/**
 * 缓存图片到本地，然后上传到云存储并落库
 * @param ctx
 * @param wallpaper
 * @returns {Promise<*>}
 */
async function saveFileToCloudStorage(ctx, wallpaper) {
    const res = await ctx.mpserverless.db.collection('wallpaper').findOne( {
        date: wallpaper.date
    } )
    if (res.affectedDocs > 0) {
        // 已经存在，跳过
        ctx.logger.info(`${wallpaper.date} already exists.`)
    } else {
        const path = `/tmp/wp${wallpaper.date}.jpg`
        const { status, data } = await ctx.httpclient.request(wallpaper.url)
        if (status === 200) {
            // 下载保存图片到本地
            await fs.writeFileSync(path, data)
            // 上传到云存储
            const result = await ctx.mpserverless.file.uploadFile( {
                filePath: path
            } )
            // 落库
            wallpaper.url = result.fileUrl
            wallpaper.fileId = result.fileId
            wallpaper.filePath = result.filePath
            await ctx.mpserverless.db.collection('wallpaper').insertOne(wallpaper)
            return wallpaper
        } else {
            ctx.logger.error(`download wallpaper error: ${res.status}`)
        }
    }
}